package uebung05.logistics;

import uebung05.logistics.material.BulletBelts;
import uebung05.logistics.material.LiterDiesel;
import uebung05.logistics.material.RocketPods;

class Demo {

    public static void main(String[] args) {
        Manager ceo = new Manager();

        Vehicle panther = new Tank("Panther");
        Vehicle leo = new Tank("Leopard 2A7");
        Vehicle tiger = new Helicopter("Tiger");
        Vehicle h125m = new Helicopter("H145M");
        Vehicle husky = new Truck("BV206-S Hägglunds");
        Vehicle zwoTonner = new Truck("Unimog2000");

        ceo.addVehicle(panther);
        ceo.addVehicle(leo);
        ceo.addVehicle(tiger);
        ceo.addVehicle(h125m);
        ceo.addVehicle(husky);
        ceo.addVehicle(zwoTonner);

        ceo.showOverallNeed();
        ceo.showNeed(LiterDiesel.getINSTANCE());
        ceo.fillUpVehicles();
        ceo.showOverallNeed();
        ceo.logTick(2);
        ceo.showOverallNeed();
        ceo.showNeed(RocketPods.getINSTANCE());
        ceo.fillUpVehicles();
        ceo.logTick(1);
        ceo.showOverallNeed();
        ceo.showNeed(BulletBelts.getINSTANCE());
    }
}
